API Reference
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   zemfrog.commands

Submodules
----------

zemfrog.app module
------------------

.. automodule:: zemfrog.app
   :members:
   :undoc-members:
   :show-inheritance:

zemfrog.cli module
------------------

.. automodule:: zemfrog.cli
   :members:
   :undoc-members:
   :show-inheritance:

zemfrog.decorators module
-------------------------

.. automodule:: zemfrog.decorators
   :members:
   :undoc-members:
   :show-inheritance:

zemfrog.exception module
------------------------

.. automodule:: zemfrog.exception
   :members:
   :undoc-members:
   :show-inheritance:

zemfrog.generator module
------------------------

.. automodule:: zemfrog.generator
   :members:
   :undoc-members:
   :show-inheritance:

zemfrog.helper module
---------------------

.. automodule:: zemfrog.helper
   :members:
   :undoc-members:
   :show-inheritance:

zemfrog.loader module
---------------------

.. automodule:: zemfrog.loader
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: zemfrog
   :members:
   :undoc-members:
   :show-inheritance:
